@@ -107,6 +107,7 @@ class EpisodeAnalytics:
             - flow and voltage by line
             - target and actual redispatch
             - attacks
+            - alarms
 
         Returns
         -------
@@ -140,6 +141,8 @@ class EpisodeAnalytics:
             "lines_modified",
             "subs_modified",
             "gens_modified",
+            "is_alarm",
+            "alarm_zone"
         ]
         action_data_table = pd.DataFrame(
             index=range(size),
@@ -159,6 +162,8 @@ class EpisodeAnalytics:
                 "lines_modified",
                 "subs_modified",
                 "gens_modified",
+                "is_alarm",
+                "alarm_zone"
             ],
         )
 
@@ -200,6 +205,10 @@ class EpisodeAnalytics:
         # objs_on_bus_2 will store the id of objects connected to bus 2
         objs_on_bus_2 = {id: [] for id in range(episode_data.observations[0].n_sub)}
 
+        is_alarm=False
+        if(("last_alarm" in episode_data.observations[0].__dict__.keys())):
+            #if(len(episode_data.observations[1].last_alarm)>=1):
+            is_alarm = (episode_data.observations[0].time_since_last_alarm[0]==0)
         # Distance from original topology is then :
         # len(line_statuses) - line_statuses.sum() + subs_on_bus_2.sum()
 
@@ -223,6 +232,14 @@ class EpisodeAnalytics:
                 act, list_actions, obs, gens_modified_ids, actual_redispatch_previous_ts
             )
 
+            alarm_zone = []
+            if (("last_alarm" in episode_data.observations[1].__dict__.keys())):
+                #is_alarm=(obs.time_since_last_alarm[0]==0)#last_alarm[1]
+                is_alarm = (obs.time_since_last_alarm[0] == 0)
+                if is_alarm:
+                    alarm_zone=[obs.alarms_area_names[zone_id]
+                                for zone_id,zone_value in enumerate(obs.last_alarm) if (int(zone_value)==time_step)]
+
             actual_redispatch_previous_ts = obs.actual_dispatch
 
             # Building load DF
@@ -263,6 +280,8 @@ class EpisodeAnalytics:
                 lines_modified,
                 subs_modified,
                 gens_modified_names,
+                is_alarm,
+                alarm_zone
             ]
 
             flow_voltage_line_table.loc[time_step, :] = np.array(
